from pyqalx.core.entities import QalxEntity


class Worker(QalxEntity):
    """QalxEntity with entity_type Worker"""

    entity_type = "worker"
